===============================
Cassandra Test of CRUD ops
===============================

.. image:: https://badge.fury.io/py/casstest.png
    :target: http://badge.fury.io/py/casstest

.. image:: https://travis-ci.org/goller/casstest.png?branch=master
        :target: https://travis-ci.org/goller/casstest

.. image:: https://pypip.in/d/casstest/badge.png
        :target: https://pypi.python.org/pypi/casstest


Just a quick dockerfile test for my entertainment

* Free software: BSD license
* Documentation: https://casstest.readthedocs.org.

Features
--------

* TODO
